@@ -1,6 +1,6 @@
 /*
     SDL - Simple DirectMedia Layer
-    Copyright (C) 1997-2009 Sam Lantinga
+    Copyright (C) 1997-2012 Sam Lantinga
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -32,21 +32,32 @@
 #include "SDL_xbios.h"
 #include "SDL_xbios_tveille.h"
 
-static tveille_t *cookie_veil;
+static tveille_t *cookie_veil = NULL;
 static int status;
 
 int SDL_XBIOS_TveillePresent(_THIS)
 {
-	return (Getcookie(C_VeiL, (unsigned long *)&cookie_veil) == C_FOUND);
+	long dummy;
+
+	cookie_veil = NULL;
+	if (Getcookie(C_VeiL, &dummy) == C_FOUND) {
+		cookie_veil = (tveille_t *) dummy;
+	}
+
+	return (cookie_veil != NULL);
 }
 
 void SDL_XBIOS_TveilleDisable(_THIS)
 {
-	status = cookie_veil->enabled;
-	cookie_veil->enabled = 0xff;
+	if (cookie_veil) {
+		status = cookie_veil->enabled;
+		cookie_veil->enabled = 0xff;
+	}
 }
 
-void SDL_XBIOS_TveilleRestore(_THIS)
+void SDL_XBIOS_TveilleEnable(_THIS)
 {
-	cookie_veil->enabled = status;
+	if (cookie_veil) {
+		cookie_veil->enabled = status;
+	}
 }
